==> spring-web-5.3.12-sources.jar: org/springframework/http/client/reactive/ClientHttpRequestDecorator.java <==
/*
 * Copyright 2002-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.http.client.reactive;

import java.net.URI;
import java.util.function.Supplier;

import org.reactivestreams.Publisher;
import reactor.core.publisher.Mono;

import org.springframework.core.io.buffer.DataBuffer;
import org.springframework.core.io.buffer.DataBufferFactory;
import org.springframework.http.HttpCookie;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.util.Assert;
import org.springframework.util.MultiValueMap;

/**
 * Wraps another {@link ClientHttpRequest} and delegates all methods to it.
 * Sub-classes can override specific methods selectively.
 *
 * @author Rossen Stoyanchev
 * @since 5.0
 */
public class ClientHttpRequestDecorator implements ClientHttpRequest {

	private final ClientHttpRequest delegate;


	public ClientHttpRequestDecorator(ClientHttpRequest delegate) {
		Assert.notNull(delegate, "Delegate is required");
		this.delegate = delegate;
	}


	public ClientHttpRequest getDelegate() {
		return this.delegate;
	}


	// ClientHttpRequest delegation methods...

	@Override
	public HttpMethod getMethod() {
		return this.delegate.getMethod();
	}

	@Override
	public URI getURI() {
		return this.delegate.getURI();
	}

	@Override
	public HttpHeaders getHeaders() {
		return this.delegate.getHeaders();
	}

	@Override
	public MultiValueMap<String, HttpCookie> getCookies() {
		return this.delegate.getCookies();
	}

	@Override
	public DataBufferFactory bufferFactory() {
		return this.delegate.bufferFactory();
	}

	@Override
	public <T> T getNativeRequest() {
		return this.delegate.getNativeRequest();
	}

	@Override
	public void beforeCommit(Supplier<? extends Mono<Void>> action) {
		this.delegate.beforeCommit(action);
	}

	@Override
	public boolean isCommitted() {
		return this.delegate.isCommitted();
	}

	@Override
	public Mono<Void> writeWith(Publisher<? extends DataBuffer> body) {
		return this.delegate.writeWith(body);
	}

	@Override
	public Mono<Void> writeAndFlushWith(Publisher<? extends Publisher<? extends DataBuffer>> body) {
		return this.delegate.writeAndFlushWith(body);
	}

	@Override
	public Mono<Void> setComplete() {
		return this.delegate.setComplete();
	}


	@Override
	public String toString() {
		return getClass().getSimpleName() + " [delegate=" + getDelegate() + "]";
	}

}

==> spring-web-6.0.13-sources.jar: org/springframework/http/client/reactive/ClientHttpRequestDecorator.java <==
/*
 * Copyright 2002-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.http.client.reactive;

import java.net.URI;
import java.util.function.Supplier;

import org.reactivestreams.Publisher;
import reactor.core.publisher.Mono;

import org.springframework.core.io.buffer.DataBuffer;
import org.springframework.core.io.buffer.DataBufferFactory;
import org.springframework.http.HttpCookie;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.util.Assert;
import org.springframework.util.MultiValueMap;

/**
 * Wraps another {@link ClientHttpRequest} and delegates all methods to it.
 * Subclasses can override specific methods selectively.
 *
 * @author Rossen Stoyanchev
 * @since 5.0
 */
public class ClientHttpRequestDecorator implements ClientHttpRequest {

	private final ClientHttpRequest delegate;


	public ClientHttpRequestDecorator(ClientHttpRequest delegate) {
		Assert.notNull(delegate, "Delegate is required");
		this.delegate = delegate;
	}


	public ClientHttpRequest getDelegate() {
		return this.delegate;
	}


	// ClientHttpRequest delegation methods...

	@Override
	public HttpMethod getMethod() {
		return this.delegate.getMethod();
	}

	@Override
	public URI getURI() {
		return this.delegate.getURI();
	}

	@Override
	public HttpHeaders getHeaders() {
		return this.delegate.getHeaders();
	}

	@Override
	public MultiValueMap<String, HttpCookie> getCookies() {
		return this.delegate.getCookies();
	}

	@Override
	public DataBufferFactory bufferFactory() {
		return this.delegate.bufferFactory();
	}

	@Override
	public <T> T getNativeRequest() {
		return this.delegate.getNativeRequest();
	}

	@Override
	public void beforeCommit(Supplier<? extends Mono<Void>> action) {
		this.delegate.beforeCommit(action);
	}

	@Override
	public boolean isCommitted() {
		return this.delegate.isCommitted();
	}

	@Override
	public Mono<Void> writeWith(Publisher<? extends DataBuffer> body) {
		return this.delegate.writeWith(body);
	}

	@Override
	public Mono<Void> writeAndFlushWith(Publisher<? extends Publisher<? extends DataBuffer>> body) {
		return this.delegate.writeAndFlushWith(body);
	}

	@Override
	public Mono<Void> setComplete() {
		return this.delegate.setComplete();
	}


	@Override
	public String toString() {
		return getClass().getSimpleName() + " [delegate=" + getDelegate() + "]";
	}

}
